==> 0.1.47.tar.gz: lib/network_resources/model/terminal.dart <==
class Terminal {
  int? placeId;
  String? placeCity;
  String? placeLabel;
  String? utcModifier;
  int? id;
  dynamic? name;
  String? authCode;
  String? ticketOptionalStr;
  int? oowoo;
  String? label;
  String? description;
  int? productId;
  String? productSerial;
  String? statusLabel;
  String? statusColor;
  String? pictureUrl;
  dynamic? password;
  String? terminalType;
  String? terminalTypeName;
  int? warrantyUntil;
  int? purchasedAt;
  dynamic? macAddress;
  dynamic? moreInfos;

  Terminal(
      {this.placeId,
      this.placeCity,
      this.placeLabel,
      this.utcModifier,
      this.id,
      this.name,
      this.authCode,
      this.ticketOptionalStr,
      this.oowoo,
      this.label,
      this.description,
      this.productId,
      this.productSerial,
      this.statusLabel,
      this.statusColor,
      this.pictureUrl,
      this.password,
      this.terminalType,
      this.terminalTypeName,
      this.warrantyUntil,
      this.purchasedAt,
      this.macAddress,
      this.moreInfos});

  Terminal.fromJson(Map<String, dynamic> json) {
    if (json["placeId"] is int) this.placeId = json["placeId"];
    if (json["placeCity"] is String) this.placeCity = json["placeCity"];
    if (json["placeLabel"] is String) this.placeLabel = json["placeLabel"];
    if (json["utcModifier"] is String) this.utcModifier = json["utcModifier"];
    if (json["id"] is int) this.id = json["id"];
    this.name = json["name"];
    if (json["authCode"] is String) this.authCode = json["authCode"];
    if (json["ticketOptionalStr"] is String)
      this.ticketOptionalStr = json["ticketOptionalStr"];
    if (json["oowoo"] is int) this.oowoo = json["oowoo"];
    if (json["label"] is String) this.label = json["label"];
    if (json["description"] is String) this.description = json["description"];
    if (json["productId"] is int) this.productId = json["productId"];
    if (json["productSerial"] is String)
      this.productSerial = json["productSerial"];
    if (json["statusLabel"] is String) this.statusLabel = json["statusLabel"];
    if (json["statusColor"] is String) this.statusColor = json["statusColor"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    this.password = json["password"];
    if (json["terminalType"] is String)
      this.terminalType = json["terminalType"];
    if (json["terminalTypeName"] is String)
      this.terminalTypeName = json["terminalTypeName"];
    if (json["warrantyUntil"] is int)
      this.warrantyUntil = json["warrantyUntil"];
    if (json["purchasedAt"] is int) this.purchasedAt = json["purchasedAt"];
    this.macAddress = json["macAddress"];
    this.moreInfos = json["moreInfos"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["placeId"] = this.placeId;
    data["placeCity"] = this.placeCity;
    data["placeLabel"] = this.placeLabel;
    data["utcModifier"] = this.utcModifier;
    data["id"] = this.id;
    data["name"] = this.name;
    data["authCode"] = this.authCode;
    data["ticketOptionalStr"] = this.ticketOptionalStr;
    data["oowoo"] = this.oowoo;
    data["label"] = this.label;
    data["description"] = this.description;
    data["productId"] = this.productId;
    data["productSerial"] = this.productSerial;
    data["statusLabel"] = this.statusLabel;
    data["statusColor"] = this.statusColor;
    data["pictureUrl"] = this.pictureUrl;
    data["password"] = this.password;
    data["terminalType"] = this.terminalType;
    data["terminalTypeName"] = this.terminalTypeName;
    data["warrantyUntil"] = this.warrantyUntil;
    data["purchasedAt"] = this.purchasedAt;
    data["macAddress"] = this.macAddress;
    data["moreInfos"] = this.moreInfos;
    return data;
  }
}

==> 0.1.97.tar.gz: lib/network_resources/model/terminal.dart <==
class Terminal {
  int? placeId;
  String? placeCity;
  String? placeLabel;
  double? placeLng;
  double? placeLat;
  String? placeCountry;
  String? placeZip;
  String? placeStreet1;
  String? placeStreet2;
  String? utcModifier;
  int? id;
  String? name;
  String? authCode;
  String? ticketOptionalStr;
  int? oowoo;
  String? label;
  String? description;
  int? productId;
  String? productSerial;
  String? statusLabel;
  String? statusColor;
  String? pictureUrl;
  String? password;
  String? terminalType;
  String? terminalTypeName;
  int? warrantyUntil;
  int? purchasedAt;
  String? macAddress;
  String? moreInfos;
  int? timeSlide;

  Terminal(
      {this.placeId,
      this.placeCity,
      this.placeLabel,
      this.placeLng,
      this.placeLat,
      this.placeCountry,
      this.placeZip,
      this.placeStreet1,
      this.placeStreet2,
      this.utcModifier,
      this.id,
      this.name,
      this.authCode,
      this.ticketOptionalStr,
      this.oowoo,
      this.label,
      this.description,
      this.productId,
      this.productSerial,
      this.statusLabel,
      this.statusColor,
      this.pictureUrl,
      this.password,
      this.terminalType,
      this.terminalTypeName,
      this.warrantyUntil,
      this.purchasedAt,
      this.macAddress,
      this.moreInfos,
      this.timeSlide});

  Terminal.fromJson(Map<String, dynamic> json) {
    if (json["placeId"] is int) this.placeId = json["placeId"];
    if (json["placeCity"] is String) this.placeCity = json["placeCity"];
    if (json["placeLabel"] is String) this.placeLabel = json["placeLabel"];
    if (json["placeLng"] is double) this.placeLng = json["placeLng"];
    if (json["placeLat"] is double) this.placeLat = json["placeLat"];
    if (json["placeCountry"] is String)
      this.placeCountry = json["placeCountry"];
    if (json["placeZip"] is String) this.placeZip = json["placeZip"];
    if (json["placeStreet1"] is String)
      this.placeStreet1 = json["placeStreet1"];
    if (json["placeStreet2"] is String)
      this.placeStreet2 = json["placeStreet2"];
    if (json["utcModifier"] is String) this.utcModifier = json["utcModifier"];
    if (json["id"] is int) this.id = json["id"];
    if (json["name"] is String) this.name = json["name"];
    if (json["authCode"] is String) this.authCode = json["authCode"];
    if (json["ticketOptionalStr"] is String)
      this.ticketOptionalStr = json["ticketOptionalStr"];
    if (json["oowoo"] is int) this.oowoo = json["oowoo"];
    if (json["label"] is String) this.label = json["label"];
    if (json["description"] is String) this.description = json["description"];
    if (json["productId"] is int) this.productId = json["productId"];
    if (json["productSerial"] is String)
      this.productSerial = json["productSerial"];
    if (json["statusLabel"] is String) this.statusLabel = json["statusLabel"];
    if (json["statusColor"] is String) this.statusColor = json["statusColor"];
    if (json["pictureUrl"] is String) this.pictureUrl = json["pictureUrl"];
    if (json["password"] is String) this.password = json["password"];
    if (json["terminalType"] is String)
      this.terminalType = json["terminalType"];
    if (json["terminalTypeName"] is String)
      this.terminalTypeName = json["terminalTypeName"];
    if (json["warrantyUntil"] is int)
      this.warrantyUntil = json["warrantyUntil"];
    if (json["purchasedAt"] is int) this.purchasedAt = json["purchasedAt"];
    if (json["macAddress"] is String) this.macAddress = json["macAddress"];
    if (json["moreInfos"] is String) this.moreInfos = json["moreInfos"];
    if (json["timeSlide"] is int) this.timeSlide = json["timeSlide"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["placeId"] = this.placeId;
    data["placeCity"] = this.placeCity;
    data["placeLabel"] = this.placeLabel;
    data["placeLng"] = this.placeLng;
    data["placeLat"] = this.placeLat;
    data["placeCountry"] = this.placeCountry;
    data["placeZip"] = this.placeZip;
    data["placeStreet1"] = this.placeStreet1;
    data["placeStreet2"] = this.placeStreet2;
    data["utcModifier"] = this.utcModifier;
    data["id"] = this.id;
    data["name"] = this.name;
    data["authCode"] = this.authCode;
    data["ticketOptionalStr"] = this.ticketOptionalStr;
    data["oowoo"] = this.oowoo;
    data["label"] = this.label;
    data["description"] = this.description;
    data["productId"] = this.productId;
    data["productSerial"] = this.productSerial;
    data["statusLabel"] = this.statusLabel;
    data["statusColor"] = this.statusColor;
    data["pictureUrl"] = this.pictureUrl;
    data["password"] = this.password;
    data["terminalType"] = this.terminalType;
    data["terminalTypeName"] = this.terminalTypeName;
    data["warrantyUntil"] = this.warrantyUntil;
    data["purchasedAt"] = this.purchasedAt;
    data["macAddress"] = this.macAddress;
    data["moreInfos"] = this.moreInfos;
    data["timeSlide"] = this.timeSlide;
    return data;
  }
}
